<?php

namespace backend\controllers;

use Yii;
use backend\models\Category;
use backend\models\CategorySearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;
use backend\models\Menu;

/**
 * CategoryController implements the CRUD actions for Category model.
 */
class CategoryController extends Controller {

    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Category models.
     * @return mixed
     */
    public function actionIndex() {
        $searchModel = new CategorySearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Category model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id) {
        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Category model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate() {
        $model = new Category();

        $restaurant_id = Yii::$app->session->get('restaurant_id');

        if ($model->load(Yii::$app->request->post())) {

            $model->restaurant_id = $restaurant_id;

            $category_name = $model->category_name;
            $image = UploadedFile::getInstance($model, 'category_image');
            if (isset($image)) {
                $changeName = 'cat_' . time() . '.' . $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/category/' . $changeName);
                $model->category_image = Yii::getAlias('@imgUrl') . '/category/' . $changeName;
            }
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('create', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Category model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id) {
        $model = $this->findModel($id);

        $restaurant_id = Yii::$app->session->get('restaurant_id');

        if ($model->load(Yii::$app->request->post())) {

            $model->restaurant_id = $restaurant_id;

            $category_name = $model->category_name;
            $image = UploadedFile::getInstance($model, 'category_image');
            if (isset($image)) {
                $changeName = 'cat_' . time() . '.' . $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/category' . $changeName);
                $model->category_image = Yii::getAlias('@imgUrl') . '/category/' . $changeName;
            } else {
                $data = Category::find()->where(['id' => $model->id])->one();
                $model->category_image = $data->category_image;
            }
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('update', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Category model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id) {
        $this->findModel($id)->delete();
        Menu::deleteMenu($id);


        return $this->redirect(['index']);
    }

    /**
     * Finds the Category model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Category the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id) {
        if (($model = Category::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
