<?php

namespace backend\controllers;

use Yii;
use yii\web\Controller;
use yii\base\InvalidParamException;
use yii\web\BadRequestHttpException;
use yii\filters\VerbFilter;
use yii\filters\AccessControl;
use common\models\LoginForm;
use backend\models\SignupForm;
use yii\web\UploadedFile;
USE common\models\User;
use backend\models\Home;
use backend\models\About;

/**
 * Site controller
 */
class SiteController extends Controller {

    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'actions' => ['signup'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                    [
                        'actions' => ['login', 'error'],
                        'allow' => true,
                    ],
                    [
                        'actions' => ['home'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                    [
                        'actions' => ['about'],
                        'allow' => true,
                        'roles' => ['?'],
                    ],
                    [
                        'actions' => ['logout', 'index'],
                        'allow' => true,
                        'roles' => ['@'],
                    ],
                ],
            ],
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'logout' => ['post'],
                ],
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function actions() {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
        ];
    }

    /**
     * Displays homepage.
     *
     * @return string
     */
    public function actionIndex() {
        return $this->render('index');
    }

    /**
     * Login action.
     *
     * @return string
     */
    public function actionLogin() {

        if (!Yii::$app->user->isGuest) {
            return $this->goHome();
        }

        $model = new LoginForm();
        if ($model->load(Yii::$app->request->post()) && $model->login()) {
           // return $this->goBack();
            return Yii::$app->getResponse()->redirect('index');
        } else {
            return $this->render('login', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Logout action.
     *
     * @return string
     */
    public function actionLogout() {
        Yii::$app->user->logout();

        return $this->goHome();
    }

    public function actionSignup() {

        $this->layout = 'signup';

        $model = new SignupForm();
        if ($model->load(Yii::$app->request->post())) {
            $restaurant_name = $model->restaurant_name;
            $image = UploadedFile::getInstance($model, 'logo');
            if (isset($image)) {
                $logoName = 'res_logo_' . time() . '.' . $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/restaurant/' . $logoName);
                $model->logo = Yii::getAlias('@imgUrl') . '/restaurant/' . $logoName;
            }

            $user = new User();

            if ($user = $model->signup()) {
                if (Yii::$app->getUser()->login($user)) {
                    Yii::$app->session->set('role', $user->role);
                    Yii::$app->session->set('restaurant_id', $user->id);
                    Yii::$app->session->set('restaurant_name', $user->restaurant_name);
                    Yii::$app->session->set('logo', $user->logo);
                    return $this->goHome();
                }
            }
        }

        return $this->render('signup', [
                    'model' => $model,
        ]);
    }

    public function actionHome() {
        $this->layout = '//home';

        $model = new Home();
        return $this->render('home', [
                    'model' => $model,
                    
        ]);
    }

    public function actionAbout() {
        $this->layout = '//home';

        $model = new About();
        return $this->render('about', [
                    'model' => $model,
        ]);
    }

}
