<?php

namespace backend\controllers;

use Yii;
use backend\models\Table;
use backend\models\TableSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use PHPExcel;
use PHPExcel_Writer_Excel2007;
use PHPExcel_IOFactory;

/**
 * TableController implements the CRUD actions for Table model.
 */
class TableController extends Controller {

    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Table models.
     * @return mixed
     */
    public function actionIndex() {
        $searchModel = new TableSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Table model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id) {
        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }

    public function actionImportExcel() {

        // $inputFile = 'web/upload/table.xlsx';
        $inputFile = 'uploads/table.xlsx';

        try {

            $inputFileType = \PHPExcel_IOFactory::identify($inputFile);
            $objReader = \PHPExcel_IOFactory::createReader($inputFileType);
            $objPHPExcel = $objReader->load($inputFile);
        } catch (yii\base\Exception $e) {
            die('Error');
        }

        $sheet = $objPHPExcel->getSheet(0);
        $highestRow = $sheet->getHighestRow();
        $highestColoumn = $sheet->getHighestColumn();

        for ($row = 1; $row <= $highestRow; $row++) {

            $rowData = $sheet->rangeToArray('A' . $row . ':' . $highestColoumn . $row, NULL, TRUE, FALSE);

            if ($row == 1) {
                continue;
            }

            $table = new Table();
            $table->restaurant_id = $rowData[0][1];
            $table->table_number = $rowData[0][2];
            $table->detail = $rowData[0][3];

            $table->save();

            print_r($table->getErrors());
        }

        die('Okay');
    }

    public function actionExport($id) {

        $model = $this->findModel($id);
        // Instantiate a new PHPExcel object 
        $objPHPExcel = new PHPExcel();
// Set the active Excel worksheet to sheet 0 
        $objPHPExcel->setActiveSheetIndex(0);
// Initialise the Excel row number 
        $rowCount = 1;

        //  while ($row = $model) {
        // Set cell An to the "name" column from the database (assuming you have a column called name)
        //    where n is the Excel row number (ie cell A1 in the first row)
        $objPHPExcel->getActiveSheet()->SetCellValue('A' . $rowCount, $model['id']);
        $objPHPExcel->getActiveSheet()->SetCellValue('B' . $rowCount, $model['restaurant_id']);
        $objPHPExcel->getActiveSheet()->SetCellValue('C' . $rowCount, $model['table_number']);
        $objPHPExcel->getActiveSheet()->SetCellValue('D' . $rowCount, $model['detail']);

        header('Content-Type: application/vnd.ms-excel');
        header('Content-Disposition: attachment;filename="Limesurvey_Results.xls"');
        header('Cache-Control: max-age=0');
        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');
        $objWriter->save('php://output');
    }

    /**
     * Creates a new Table model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate() {
        $model = new Table();
        $restaurant_id = Yii::$app->session->get('restaurant_id');

        if ($model->load(Yii::$app->request->post())) {

            $model->restaurant_id = $restaurant_id;
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('create', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Table model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id) {
        $model = $this->findModel($id);
        $restaurant_id = Yii::$app->session->get('restaurant_id');

        if ($model->load(Yii::$app->request->post())) {

            $model->restaurant_id = $restaurant_id;
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('update', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Table model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id) {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Table model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Table the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id) {
        if (($model = Table::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
