<?php

namespace backend\controllers;

use backend\models\ForgotpasswordForm;
use Yii;
use backend\models\User;
use backend\models\UserSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;

/**
 * UserController implements the CRUD actions for User model.
 */
class UserController extends Controller {

    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all User models.
     * @return mixed
     */
    public function actionIndex() {
        $searchModel = new UserSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single User model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id) {
        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }

    public function actionAbout($id) {
        return $this->render('about', [
                    'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new User model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate() {
        $model = new User();

        if ($model->load(Yii::$app->request->post())) {

            $first_name = $model->owner_firstname;
            $model->created_at = time();
            $model->updated_at = time();

            $image = UploadedFile::getInstance($model, 'logo');
            if (isset($image)) {
                $changeName = 'user_' . time() . '.' . $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/user/' . $changeName);
                $model->logo = Yii::getAlias('@imgUrl') . '/user/' . $changeName;
            } else {
                $model->logo = User::find('logo')->where(['id' => $model->id])->one();
            }
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('create', [
                        'model' => $model,
            ]);
        }
    }

    public function actionSignup() {

        $model = new User();

        if ($model->load(Yii::$app->request->post())) {

            $first_name = $model->owner_firstname;
            $model->created_at = time();
            $model->updated_at = time();

            $image = UploadedFile::getInstance($model, 'logo');
            if (isset($image)) {
                $changeName = 'user_' . time() . '.' . $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/user/' . $changeName);
                $model->logo = Yii::getAlias('@imgUrl') . '/user/' . $changeName;
            }
            $model->save();

            return $this->redirect(['site/login']);
        } else {
            return $this->render('signup', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing User model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id) {
        $model = $this->findModel($id);

        if ($model->load(Yii::$app->request->post())) {
            $first_name = $model->owner_firstname;
            $model->updated_at = time();

            $image = UploadedFile::getInstance($model, 'logo');
            if (isset($image)) {
                $changeName = 'user_' . time() . '.' . $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/user/' . $changeName);
                $model->logo = Yii::getAlias('@imgUrl') . '/user/' . $changeName;
            } else {
                $data = User::find()->where(['id' => $model->id])->one();
                $model->logo = $data->logo;
            }
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('update', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing User model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id) {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    public function actionResetPassword($id) {
        // $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    public function actionForgotpassword($id) {

        $model1 = new ForgotpasswordForm();
        if ($model1->load(Yii::$app->request->post()) && $model1->validate()) {

            if ($model1->comparePass()) {
                $connection = Yii::$app->db;
                $res = $connection->createCommand()->update('user', ['password' => $model1->newpass], 'id =' . $id)->execute();
                $query = User::find()->where(['id' => $id])->one();
                if ($res && $model1->sendEmail($query->email, $query->password)) {
                    Yii::$app->session->setFlash('success', 'Thank you your password has been changed successfully.');
                } else {
                    Yii::$app->session->setFlash('error', 'There was an error please try again.');
                }

                return $this->refresh();
            } else {
                Yii::$app->session->setFlash('error', 'Confirm password should be same.');
                return $this->refresh();
            }
        } else {
            return $this->render('forgotpassword', [
                        'model' => $model1,
            ]);
        }
    }

    /**
     * Finds the User model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return User the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id) {
        if (($model = User::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
