<?php

namespace backend\controllers;

use Yii;
use backend\models\Waiter;
use backend\models\WaiterSearch;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;

/**
 * WaiterController implements the CRUD actions for Waiter model.
 */
class WaiterController extends Controller {

    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }

    /**
     * Lists all Waiter models.
     * @return mixed
     */
    public function actionIndex() {
        $searchModel = new WaiterSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);

        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }

    /**
     * Displays a single Waiter model.
     * @param integer $id
     * @return mixed
     */
    public function actionView($id) {
        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }

    /**
     * Creates a new Waiter model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     * @return mixed
     */
    public function actionCreate() {
        $model = new Waiter();

        $restaurant_id = Yii::$app->session->get('restaurant_id');

        if ($model->load(Yii::$app->request->post())) {
            $model->restaurant_id = $restaurant_id;

            $name = $model->name;
            $image = UploadedFile::getInstance($model, 'image');
            if (isset($image)) {
                $changeName = 'waiter_' . time() .'.'. $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/waiter/' . $changeName);
                $model->image = Yii::getAlias('@imgUrl') . '/waiter/' . $changeName;
            }

            $model->save();
            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('create', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Updates an existing Waiter model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id
     * @return mixed
     */
    public function actionUpdate($id) {
        $model = $this->findModel($id);

        $restaurant_id = Yii::$app->session->get('restaurant_id');

        if ($model->load(Yii::$app->request->post())) {
            $model->restaurant_id = $restaurant_id;

            $name = $model->name;
            $image = UploadedFile::getInstance($model, 'image');
            if (isset($image)) {
                $changeName = 'waiter_' . time() .'.'. $image->getExtension();
                $image->saveAs(Yii::getAlias('@path') . '/waiter/' . $changeName);
                $model->image = Yii::getAlias('@imgUrl') . '/waiter/' . $changeName;
            } else {
                $data = Waiter::find()->where(['id' => $model->id])->one();
                $model->image = $data->image;
            }
            $model->save();

            return $this->redirect(['view', 'id' => $model->id]);
        } else {
            return $this->render('update', [
                        'model' => $model,
            ]);
        }
    }

    /**
     * Deletes an existing Waiter model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     * @param integer $id
     * @return mixed
     */
    public function actionDelete($id) {
        $this->findModel($id)->delete();

        return $this->redirect(['index']);
    }

    /**
     * Finds the Waiter model based on its primary key value.
     * If the model is not found, a 404 HTTP exception will be thrown.
     * @param integer $id
     * @return Waiter the loaded model
     * @throws NotFoundHttpException if the model cannot be found
     */
    protected function findModel($id) {
        if (($model = Waiter::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }

}
