<?php

namespace backend\models;

use yii\base\Model;
use common\models\User;
use yii\web\UploadedFile;

/**
 * Signup form
 */
class SignupForm extends Model {

    public $restaurant_name;
    public $owner_firstname;
    public $owner_lastname;
    public $phone_no;
    public $landline_no;
    public $logo;
    public $email;
    public $password;

    /**
     * @inheritdoc
     */
    public function rules() {
        return [
            //['username', 'trim'],
            //['username', 'unique', 'targetClass' => '\common\models\User', 'message' => 'This username has already been taken.'],
            // ['username', 'string', 'min' => 2, 'max' => 255],
            ['restaurant_name', 'required'],
            ['owner_firstname', 'required'],
            ['owner_lastname', 'required'],
            ['phone_no', 'required'],
            ['phone_no', 'number', 'min' => 10],
            ['landline_no', 'required'],
            ['landline_no', 'number'],
            ['logo', 'safe'],
            ['logo', 'file', 'extensions' => 'jpg,gif,png'],
            ['email', 'string', 'max' => 255],
            ['email', 'trim'],
            ['email', 'required'],
            ['email', 'email'],
            ['email', 'unique', 'targetClass' => '\common\models\User', 'message' => 'This email address has already been taken.'],
            //['email', 'unique', 'targetAttribute' => 'email', 'message' => 'This email address has already been taken.'],
            ['password', 'required'],
            ['password', 'string', 'min' => 6],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels() {
        return [
            'phone_no' => 'Mobile No.',
        ];
    }

    /**
     * Signs user up.
     *
     * @return User|null the saved model or null if saving fails
     */
    public function signup() {
        if (!$this->validate()) {
            return null;
        }

        $user = new User();
        $user->restaurant_name = $this->restaurant_name;
        $user->owner_firstname = $this->owner_firstname;
        $user->owner_lastname = $this->owner_lastname;
        $user->phone_no = $this->phone_no;
        $user->landline_no = $this->landline_no;
        $user->logo = $this->logo;
        $user->email = $this->email;
        $user->password = $this->password;
        $user->generateAuthKey();
   
        return $user->save() ? $user : null;
    }

}
