<?php

namespace backend\models;

use Yii;

/**
 * This is the model class for table "user".
 *
 * @property integer $id
 * @property string $restaurant_name
 * @property string $owner_firstname
 * @property string $owner_lastname
 * @property string $email
 * @property string $password
 * @property string $phone_no
 * @property string $landline_no
 * @property string $logo
 * @property integer $role
 * @property integer $isActive
 * @property string $username
 * @property string $auth_key
 * @property string $password_hash
 * @property string $password_reset_token
 * @property integer $status
 * @property integer $created_at
 * @property integer $updated_at
 *
 * @property Category[] $categories
 * @property Table $table
 * @property Waiter[] $waiters
 */
class User extends \yii\db\ActiveRecord {

    /**
     * @inheritdoc
     */
    public static function tableName() {
        return 'user';
    }

    /**
     * @inheritdoc
     */
    public function rules() {
        return [
            [['owner_firstname', 'owner_lastname', 'email', 'password', 'phone_no', 'landline_no', 'role'], 'required'],
            [['role', 'isActive', 'status', 'created_at', 'updated_at'], 'integer'],
            [['restaurant_name'], 'string', 'max' => 200],
            [['owner_firstname', 'owner_lastname', 'password'], 'string', 'max' => 60],
            [['email'], 'string', 'max' => 100],
            [['phone_no', 'landline_no'], 'string', 'max' => 20],
            [['about'], 'string'],
            [['logo'], 'string', 'max' => 400],
            [['username', 'password_hash', 'password_reset_token'], 'string', 'max' => 255],
            [['auth_key'], 'string', 'max' => 32],
            [['email'], 'unique'],
            [['password_reset_token'], 'unique'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels() {
        return [
            'id' => 'ID',
            'restaurant_name' => 'Restaurant Name',
            'owner_firstname' => 'Owner Firstname',
            'owner_lastname' => 'Owner Lastname',
            'email' => 'Email',
            'password' => 'Password',
            'phone_no' => 'Phone No',
            'landline_no' => 'Landline No',
            'logo' => 'Logo',
            'role' => 'Role',
            'about' => 'About Us',
            'isActive' => 'Is Active',
            'username' => 'Username',
            'auth_key' => 'Auth Key',
            'password_hash' => 'Password Hash',
            'password_reset_token' => 'Password Reset Token',
            'status' => 'Status',
            'created_at' => 'Created At',
            'updated_at' => 'Updated At',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCategories() {
        return $this->hasMany(Category::className(), ['restaurant_id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getTable() {
        return $this->hasOne(Table::className(), ['id' => 'id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getWaiters() {
        return $this->hasMany(Waiter::className(), ['restaurant_id' => 'id']);
    }

}
