<?php

namespace backend\modules\api\models;

use Yii;

/**
 * This is the model class for table "menu".
 *
 * @property integer $id
 * @property integer $category_id
 * @property string $menu_name
 * @property string $menu_image
 * @property string $menu_price_half
 * @property string $menu_price_full
 * @property string $menu_detail
 *
 * @property Category $category
 * @property Topping[] $toppings
 */
class Menu extends \yii\db\ActiveRecord
{

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'menu';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['category_id', 'menu_name', 'menu_image', 'menu_price_half', 'menu_detail'], 'required'],
            [['category_id'], 'integer'],
            [['menu_detail'], 'string'],
            [['menu_name', 'menu_image'], 'string', 'max' => 200],
            [['menu_price_half'], 'string', 'max' => 20],
            [['menu_price_full'], 'string', 'max' => 10],
            [['category_id'], 'exist', 'skipOnError' => true, 'targetClass' => Category::className(), 'targetAttribute' => ['category_id' => 'id']],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'category_id' => 'Category ID',
            'menu_name' => 'Menu Name',
            'menu_image' => 'Menu Image',
            'menu_price_half' => 'Menu Price Half',
            'menu_price_full' => 'Menu Price Full',
            'menu_detail' => 'Menu Detail',
        ];
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getCategory()
    {
        return $this->hasOne(Category::className(), ['id' => 'category_id']);
    }

    /**
     * @return \yii\db\ActiveQuery
     */
    public function getToppings()
    {
        return $this->hasMany(Topping::className(), ['menu_id' => 'id']);
    }
}
